#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Indicator;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Strategy;
using System.Collections.Generic;
#endregion
// Add System.Collections so we can use ArrayLists
//using System.Collections;

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    /// <summary>
    /// 
    /// </summary>
    [Description("")]
    public class TestNEW : Strategy
    {
        #region Variables
       
        private int fast = 3; // Default setting for Fast
        private int slow = 50; // Default setting for Slow	
		private double distance = .03;
        #endregion
        
												
public class StockEntry
{
  public string Name;
  public PeriodType Period;
  public int Value;
  public int Count;

public StockEntry(string Name, PeriodType Period, int Value, int Count)
{
	this.Name = Name;
	this.Period = Period;
	this.Value = Value;
	this.Count = Count;
}	
}
List<StockEntry> _stocks = new List<StockEntry>();

 protected override void Initialize()
        {						

			
#region Primary 5min			
//Primary 5min
_stocks.Add(new StockEntry("ABC", PeriodType.Minute, 5, 0));			
_stocks.Add(new StockEntry("ACE", PeriodType.Minute, 5, 0));
_stocks.Add(new StockEntry("ACN", PeriodType.Minute, 5, 0));
_stocks.Add(new StockEntry("ADT", PeriodType.Minute, 5, 0));
_stocks.Add(new StockEntry("SCTY", PeriodType.Minute, 5, 0));
#endregion

#region Secondary 1min
_stocks.Add(new StockEntry("ABC", PeriodType.Minute, 1, 0));			
_stocks.Add(new StockEntry("ACE", PeriodType.Minute, 1, 0));
_stocks.Add(new StockEntry("ACN", PeriodType.Minute, 1, 0));
_stocks.Add(new StockEntry("ADT", PeriodType.Minute, 1, 0));
_stocks.Add(new StockEntry("SCTY", PeriodType.Minute, 1, 0));
#endregion
			
			Add(SMA(Fast));
            Add(SMA(Slow));
			
			EntriesPerDirection = 1;
			EntryHandling = EntryHandling.UniqueEntries;
							
            CalculateOnBarClose = true;
			
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        
        {  
			//for loop to iterate each instrument through, "series" is 5min of each instrument, "series + 5" is 1min of each instrument.
			for (int series = 0; series < 5; series++)
			if (BarsInProgress == series + 5) //OnBarUpdate called for 1min bars
			{	 
				
				bool enterTrade = false;
				
			    if (_stocks[series].Count < 1)
				{
				enterTrade = true;
				}
				else
				{
				enterTrade = BarsSinceEntry(series, "", 0) > 2; 
				} 

                if (enterTrade)
				  {  // Condition set 1 Long Entry, fast MA cross above slow MA & current price > high of bar at cross.
	                if (SMA(BarsArray[series],Fast)[1] > SMA(BarsArray[series],Slow)[1] && 
					SMA(BarsArray[series],Fast)[2] < SMA(BarsArray[series],Slow)[2] && Closes[series + 5][0] > Highs[series][1] + distance 
					&& SMA(BarsArray[series],Slow)[1] > SMA(BarsArray[series],Slow)[2] + .01) 
									


                  EnterLong(200);
					 
						_stocks[series].Count++;

				  }
            } 
		
	
			
		}
		
			
        

        #region Properties
        [Description("Fast MA Period")]
        [GridCategory("Parameters")]
        public int Fast
        {
            get { return fast; }
            set { fast = Math.Max(1, value); }
        }

        [Description("Slow MA Period")]
        [GridCategory("Parameters")]
        public int Slow
        {
            get { return slow; }
            set { slow = Math.Max(1, value); }
        }
		
		
		
		[Description("")]
		[Category("Parameters")]
		public double Distance
		{
			get { return distance; }  
			set { distance = Math.Max(0, value); }
		}
		
		
        #endregion
    }
}
